using System;
using System.Collections.Generic;
using System.Text;
using System.ComponentModel;
using System.Reflection;

namespace Unum.Benefits.UI.Common.Binding
{
    /// <summary>
    /// The base definition of a BindingAdapter.
    /// </summary>
    public abstract class BindingAdapter
    {
        #region Methods

        /// <summary>
        /// This method is called just before a view expands an object.
        /// Override this method to implement lazy loading scenarios.
        /// </summary>
        public virtual void Expand()
        {
        }

        /// <summary>
        /// Gets a collection of property descriptors for the given BindingAdapter implementation.
        /// </summary>
        /// <typeparam name="TType">The BindingAdapter derived type to get property descriptors for.</typeparam>
        /// <returns>A collection of property descriptors for this binding adapter.</returns>
        public static PropertyDescriptorCollection GetPropertyDescriptors<TType>() where TType : BindingAdapter
        {
            return GetPropertyDescriptors(typeof(TType));
        }

        /// <summary>
        /// Gets a collection of property descriptors for the given BindingAdapter implementation.
        /// </summary>
        /// <param name="adapterType">
        /// The BindingAdapter derived type to get property descriptors for.
        /// If the given type is not derived from BindingAdapter then an exception will be thrown.
        /// </param>
        /// <returns>A collection of property descriptors for this binding adapter.</returns>
        public static PropertyDescriptorCollection GetPropertyDescriptors(Type adapterType)
        {
            if (!typeof(BindingAdapter).IsAssignableFrom(adapterType))
                throw new ApplicationException("Only BindingAdapter derived types are supported by this method.");

            PropertyDescriptorCollection props = TypeDescriptor.GetProperties(adapterType);
            return props;
        }

        #endregion
    }
}
