using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Text;
using System.Windows.Forms;
using System.IO;

using Infragistics.Win.UltraWinGrid;
using Infragistics.Win;

using Unum.Benefits.UI.Common.Binding;

namespace Unum.Benefits.UI.Common.Forms
{
    /// <summary>
    /// A grid control that supports the Unum.Compensation.Entity.Binding classes.
    /// </summary>
    public partial class UnumGrid : UltraGrid
    {
        #region Constructors

        /// <summary>
        /// Constructor.
        /// </summary>
        public UnumGrid()
        {
            // action that moves selection to previous row on left click
            GridKeyActionMapping mapping = new GridKeyActionMapping(
                Keys.Left,
                UltraGridAction.PrevRow,
                UltraGridState.Cell | UltraGridState.RowExpandable,
                UltraGridState.Row | UltraGridState.RowExpanded,
                SpecialKeys.Alt,
                0);
            this.KeyActionMappings.Add(mapping);
        }

        #endregion

        #region Methods

        /// <summary>
        /// If the row is bound to a BindingAdapter the Expand method is called.
        /// </summary>
        /// <param name="e">Event arguments.</param>
        protected override void OnBeforeRowExpanded(CancelableRowEventArgs e)
        {
            base.OnBeforeRowExpanded(e);

            BindingAdapter adapter = e.Row.ListObject as BindingAdapter;
            if (adapter != null)
            {
                adapter.Expand();

                // force refresh of data
                CurrencyManager cm = this.BindingContext[this.DataSource] as CurrencyManager;
                if (cm != null)
                    cm.Refresh();
            }            
        }

        #endregion
    }
}
